==> ejc-procost-impl-3.0.0-20220316.024813-1-sources.jar: com/ejianc/business/procost/bean/ShareEntity.java <==
package com.ejianc.business.procost.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * 成本分摊
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_share")
public class ShareEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="tax_flag")
    private java.lang.String taxFlag; // 是否含税 0-是，1-否
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="material_cost")
    private java.lang.String materialCost; // 物资成本 0-出库入成本，1-物资合同结算入成本
    @TableField(value="period")
    private java.lang.String period; // 期间
    @TableField(value="last_period")
    private java.lang.String lastPeriod; // 上期核算期间
    @TableField(value="last_cost_mny")
    private java.math.BigDecimal lastCostMny; // 上期分摊成本
    @TableField(value="sum_cost_mny")
    private java.math.BigDecimal sumCostMny; // 累计分摊成本
    @TableField(value="cost_mny")
    private java.math.BigDecimal costMny; // 本期分摊成本
    @TableField(value="un_cost_mny")
    private java.math.BigDecimal unCostMny; // 待分摊成本
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 创建人名称
    @TableField(value="end_day")
    private java.lang.String endDay; // 当前期间最后一天


    @TableField(exist = false)
    @SubEntity(serviceName="shareDetailService",pidName = "shareId")
    private List<ShareDetailEntity> shareDetail = new ArrayList<ShareDetailEntity>();

    public List<ShareDetailEntity> getShareDetail() {
        return shareDetail;
    }

    public void setShareDetail(List<ShareDetailEntity> shareDetail) {
        this.shareDetail = shareDetail;
    }

    public String getEndDay() {
        return endDay;
    }

    public void setEndDay(String endDay) {
        this.endDay = endDay;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public java.lang.String getTaxFlag() {
        return taxFlag;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public void setTaxFlag(java.lang.String taxFlag) {
        this.taxFlag = taxFlag;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public java.lang.String getMaterialCost() {
        return materialCost;
    }

    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public void setMaterialCost(java.lang.String materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 期间
     */
    public java.lang.String getPeriod() {
        return period;
    }

    /**
     * 期间
     */
    public void setPeriod(java.lang.String period) {
        this.period = period;
    }
    /**
     * 上期核算期间
     */
    public java.lang.String getLastPeriod() {
        return lastPeriod;
    }

    /**
     * 上期核算期间
     */
    public void setLastPeriod(java.lang.String lastPeriod) {
        this.lastPeriod = lastPeriod;
    }
    /**
     * 上期分摊成本
     */
    public java.math.BigDecimal getLastCostMny() {
        return lastCostMny;
    }

    /**
     * 上期分摊成本
     */
    public void setLastCostMny(java.math.BigDecimal lastCostMny) {
        this.lastCostMny = lastCostMny;
    }
    /**
     * 累计分摊成本
     */
    public java.math.BigDecimal getSumCostMny() {
        return sumCostMny;
    }

    /**
     * 累计分摊成本
     */
    public void setSumCostMny(java.math.BigDecimal sumCostMny) {
        this.sumCostMny = sumCostMny;
    }
    /**
     * 本期分摊成本
     */
    public java.math.BigDecimal getCostMny() {
        return costMny;
    }

    /**
     * 本期分摊成本
     */
    public void setCostMny(java.math.BigDecimal costMny) {
        this.costMny = costMny;
    }
    /**
     * 待分摊成本
     */
    public java.math.BigDecimal getUnCostMny() {
        return unCostMny;
    }

    /**
     * 待分摊成本
     */
    public void setUnCostMny(java.math.BigDecimal unCostMny) {
        this.unCostMny = unCostMny;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}

==> ejc-procost-impl-3.0.0-20230207.034545-166-sources.jar: com/ejianc/business/procost/bean/ShareEntity.java <==
package com.ejianc.business.procost.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * 成本分摊
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_share")
public class ShareEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="tax_flag")
    private java.lang.String taxFlag; // 是否含税 0-是，1-否
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级组织Id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部上级组织名称
    @TableField(value="material_cost")
    private java.lang.String materialCost; // 物资成本 0-出库入成本，1-物资合同结算入成本
    @TableField(value="period")
    private java.lang.String period; // 期间
    @TableField(value="last_period")
    private java.lang.String lastPeriod; // 上期核算期间
    @TableField(value="last_cost_mny")
    private java.math.BigDecimal lastCostMny; // 上期分摊成本
    @TableField(value="sum_cost_mny")
    private java.math.BigDecimal sumCostMny; // 累计分摊成本
    @TableField(value="cost_mny")
    private java.math.BigDecimal costMny; // 本期分摊成本
    @TableField(value="un_cost_mny")
    private java.math.BigDecimal unCostMny; // 待分摊成本
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 创建人名称
    @TableField(value="end_day")
    private java.lang.String endDay; // 当前期间最后一天
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称


    @TableField(exist = false)
    @SubEntity(serviceName="shareDetailService",pidName = "shareId")
    private List<ShareDetailEntity> shareDetail = new ArrayList<ShareDetailEntity>();

    public List<ShareDetailEntity> getShareDetail() {
        return shareDetail;
    }

    public void setShareDetail(List<ShareDetailEntity> shareDetail) {
        this.shareDetail = shareDetail;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public String getEndDay() {
        return endDay;
    }

    public void setEndDay(String endDay) {
        this.endDay = endDay;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public java.lang.String getTaxFlag() {
        return taxFlag;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public void setTaxFlag(java.lang.String taxFlag) {
        this.taxFlag = taxFlag;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public java.lang.String getMaterialCost() {
        return materialCost;
    }

    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public void setMaterialCost(java.lang.String materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 期间
     */
    public java.lang.String getPeriod() {
        return period;
    }

    /**
     * 期间
     */
    public void setPeriod(java.lang.String period) {
        this.period = period;
    }
    /**
     * 上期核算期间
     */
    public java.lang.String getLastPeriod() {
        return lastPeriod;
    }

    /**
     * 上期核算期间
     */
    public void setLastPeriod(java.lang.String lastPeriod) {
        this.lastPeriod = lastPeriod;
    }
    /**
     * 上期分摊成本
     */
    public java.math.BigDecimal getLastCostMny() {
        return lastCostMny;
    }

    /**
     * 上期分摊成本
     */
    public void setLastCostMny(java.math.BigDecimal lastCostMny) {
        this.lastCostMny = lastCostMny;
    }
    /**
     * 累计分摊成本
     */
    public java.math.BigDecimal getSumCostMny() {
        return sumCostMny;
    }

    /**
     * 累计分摊成本
     */
    public void setSumCostMny(java.math.BigDecimal sumCostMny) {
        this.sumCostMny = sumCostMny;
    }
    /**
     * 本期分摊成本
     */
    public java.math.BigDecimal getCostMny() {
        return costMny;
    }

    /**
     * 本期分摊成本
     */
    public void setCostMny(java.math.BigDecimal costMny) {
        this.costMny = costMny;
    }
    /**
     * 待分摊成本
     */
    public java.math.BigDecimal getUnCostMny() {
        return unCostMny;
    }

    /**
     * 待分摊成本
     */
    public void setUnCostMny(java.math.BigDecimal unCostMny) {
        this.unCostMny = unCostMny;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}
